$set 3 #Configmenu

$ #ConfigOptions
# պAﶵ 
$ #FocusModel
# мҦ]w
$ #WindowPlacement
# m]w
$ #ImageDithering
# Ϲݰy
$ #OpaqueMove
# ʤz]w 
$ #FullMax
# ̤jƦܥù 
$ #FocusNew
# Ьs 
$ #FocusLast
# u@ܤƦ۰ʫЦܵ
$ #ClickToFocus
# Iѹ 
$ #SloppyFocus
# ۰ʫзbW 
$ #AutoRaise
# ۰ʳ̤Wh 
$ #SmartRows
# ۰ʩmsm () 
$ #SmartCols
# ۰ʩmsm (C)
$ #Cascade
# |msm 
$ #LeftRight
# ѥܥk 
$ #RightLeft
# ѥkܥ 
$ #TopBottom
# ѤWܤU 
$ #BottomTop
# ѤUܤW 
$ #NoDithering
# Do not dither images
$ #OrderedDithering
# Use fast dither
$ #FloydSteinbergDithering
# Use high-quality dither
